var bluez_autoswitch_8c =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "node", "structnode.html", "structnode" ],
    [ "find_data", "structfind__data.html", "structfind__data" ],
    [ "DEFAULT_AUDIO_SINK_KEY", "bluez-autoswitch_8c.html#ae6a51a1ae9635ff30bd113b6b698be11", null ],
    [ "NAME", "bluez-autoswitch_8c.html#a47f2e62c0dbebc787052c165afcada0e", null ],
    [ "PW_LOG_TOPIC_DEFAULT", "bluez-autoswitch_8c.html#a37f02197895628b68a81bc1ef06d0f65", null ],
    [ "RESTORE_DELAY_SEC", "bluez-autoswitch_8c.html#ae61b871e183d99fb52cae34575faac9d", null ],
    [ "SESSION_KEY", "bluez-autoswitch_8c.html#a894b84c8f5ff621bf7f7ed71c990b651", null ],
    [ "get_pending_save", "bluez-autoswitch_8c.html#a0fa8f86b49f5273b0987658921f3dae5", null ],
    [ "get_saved_headset_profile", "bluez-autoswitch_8c.html#aa2e8090a21f32e302e3dd61096834574", null ],
    [ "get_saved_profile", "bluez-autoswitch_8c.html#aa72d890990913dbedfca39ff1d7aeaa3", null ],
    [ "PW_LOG_TOPIC_STATIC", "bluez-autoswitch_8c.html#a32cef58a621827e475f6e0c51cdfe973", null ],
    [ "set_pending_save", "bluez-autoswitch_8c.html#aab67c3a9eae016857c1231caf50a9ac1", null ],
    [ "set_saved_headset_profile", "bluez-autoswitch_8c.html#a7a95f5a8add9d7eda9c69b869aa99b64", null ],
    [ "set_saved_profile", "bluez-autoswitch_8c.html#a87cc4fb2427aff65828e5f5c74ac2411", null ],
    [ "sm_bluez5_autoswitch_start", "bluez-autoswitch_8c.html#a3ca694e3fdfbe66ca8625f34c02d1191", null ]
];